@@ -106,6 +106,7 @@ sub execute {
             output({stderr=>1,color=>'red'}, "Unknown profile '$profile', valid profiles: " .
                     join(', ', sort keys %profiles)
             );
+            exit 1;
         }
     }
     elsif(exists $opt->{add}) {
@@ -120,6 +121,10 @@ sub execute {
             push @files_to_edit, _default_file($profile,$file);
         }
     }
+    else {
+        output({stderr=>1,color=>'red'}, "No action specified, nothing to do.");
+        exit 1;
+    }
 
     # Edit files in the list.
     foreach my $filename (@files_to_edit) {
@@ -187,7 +192,7 @@ Git::Code::Review::Command::profile - Manage profiles for the code selection
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 AUTHOR
 
