@@ -12,8 +12,6 @@ use Sys::Hostname qw(hostname);
 
 # Globals
 my %HEADERS = (
-    'Importance'            => 'High',
-    'Priority'              => 'urgent',
     'Sensitivity'           => 'company confidential',
     'X-Automation-Program'  => $0,
     'X-Automation-Function' => 'Git::Code::Review',
@@ -40,10 +38,17 @@ sub send {
     my $data = delete $config{message};
     die "Message empty" unless defined $data && length $data > 0;
 
+    # Set urgency
+    if($config{priority} eq 'high') {
+        $config{headers}->{Importance} = 'High';
+        $config{headers}->{Priority}   = 'urgent';
+    }
+
     # Generate the email to send
     if( defined $data && length $data ) {
         debug("Evaluated template and received: ", $data);
-        my $subject  = sprintf('Git::Code::Review %s %s=%s',
+        my $subject  = sprintf('%sGit::Code::Review %s %s=%s',
+            $config{priority} eq 'high' ? '[CRITICAL] ' : '',
             uc $config{name},
             (exists $config{commit} ? "COMMIT" : "REPO"),
             (exists $config{commit} ? $config{commit}->{sha1} : gcr_origin('source')),
@@ -115,7 +120,7 @@ Git::Code::Review::Notify::Email - Notification by email
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 AUTHOR
 
