@@ -3,7 +3,7 @@ package Git::Code::Review::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '1.5'; # VERSION
+our $VERSION = '1.6'; # VERSION
 
 # Utility Modules
 use CLI::Helpers qw(:all);
@@ -318,16 +318,23 @@ sub gcr_commit_exists {
 }
 
 
+my %_commit_info;
 sub gcr_commit_info {
     my ($object) = @_;
+
     my $audit = gcr_repo();
     # Object can be a sha1, path in the repo, or patch
-    my ($_line,$_sub) = (caller 1)[2,3];
-
     my @matches = grep /\.patch$/, $audit->run('ls-files', "*$object*");
     if( @matches != 1 ) {
-        die sprintf('gcr_commit_info("%s") %s commit object: %s line %d', $object, (@matches > 1 ? 'ambiguous' : 'unknown'), $_sub, $_line);
+        die sprintf('gcr_commit_info("%s") %s commit object', $object, (@matches > 1 ? 'ambiguous' : 'unknown'));
     }
+
+    # Caching, do this only once per run
+    my $base = basename($matches[0]);
+    if( exists $_commit_info{$base} ) {
+        return wantarray ? %{ $_commit_info{$base} } : \%{ $_commit_info{$base} };
+    }
+
     my %commit = (
         base         => basename($matches[0]),
         date         => _get_commit_date($matches[0]),
@@ -344,20 +351,18 @@ sub gcr_commit_info {
     );
     $commit{select_date} = _get_commit_select_date($commit{sha1});
 
+    $_commit_info{$base} = \%commit;
     return wantarray ? %commit : \%commit;
 }
 
 sub gcr_commit_profile {
     my ($object) = @_;
-    my ($_line,$_sub) = (caller 1)[2,3];
-
-    die "Invalid call to gcr_commit_profile() from  $_sub at $_line" unless $object;
 
     my $audit = gcr_repo();
     # Object can be a sha1, path in the repo, or patch
     my @matches = $audit->run('ls-files', "*$object*");
     if( @matches != 1 ) {
-        verbose({color=>'yellow',indent=>1}, sprintf 'gcr_commit_profile("%s") %s commit object from %s line %d', $object, (@matches > 1 ? 'ambiguous' : 'unknown'), $_sub, $_line);
+        verbose({color=>'yellow',indent=>1}, sprintf 'gcr_commit_profile("%s") %s commit object from', $object, (@matches > 1 ? 'ambiguous' : 'unknown'));
         return;
     }
 
@@ -572,7 +577,7 @@ sub gcr_commit_message {
     my %details = (
         context => {
             pid      => $$,
-            hostanme => hostname(),
+            hostname => hostname(),
             pwd      => getcwd,
         },
     );
@@ -597,7 +602,6 @@ sub gcr_commit_message {
 sub gcr_audit_commit {
     my($audit_sha1) = @_;
     my $audit = gcr_repo();
-    my ($_line,$_sub) = (caller 1)[2,3];
 
     # Get a list of files in the commit that end in .patch
     my %c = map { $_ => 1 }
@@ -606,7 +610,7 @@ sub gcr_audit_commit {
 
     my @commits = keys %c;
     if(@commits != 1) {
-        verbose({color=>'red',indent=>1}, sprintf "gcr_audit_commit('%s') contains %d source commits (%s - line %d)\n", $audit_sha1, scalar(@commits), $_sub, $_line );
+        verbose({color=>'red',indent=>1}, sprintf "gcr_audit_commit('%s') contains %d source commits", $audit_sha1, scalar(@commits));
         return;
     }
 
@@ -616,7 +620,6 @@ sub gcr_audit_commit {
 sub gcr_audit_files {
     my($audit_sha1) = @_;
     my $audit = gcr_repo();
-    my ($_line,$_sub) = (caller 1)[2,3];
 
     # Get a list of files in the commit that end in .patch
     my @files = grep { /\.patch$/ } $audit->run(qw(diff-tree --no-commit-id --name-only -r), $audit_sha1);
@@ -829,7 +832,7 @@ Git::Code::Review::Utilities - Tools for performing code review using Git as the
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 FUNCTIONS
 
